
input        { background-color: #fff; margin: 0; text-align: left;
               outline: none !important; }
pre, code, table.source,
textarea     { font-family: Consolas, "andale mono", "lucida console", monospace; font-size: 14px; }

div.debugger { text-align: left; padding: 12px; margin: auto;
               background-color: white; }
h1           { margin: 0 0 0.3em 0; }
div.detail p { margin: 0 0 8px 13px; font-size: 14px; }
div.detail pre.errormsg { word-wrap: break-word; }
div.explanation { margin: 20px 13px; font-size: 15px; color: #555; }
div.footer   { font-size: 13px; text-align: right; margin: 30px 0;
               color: #999999; }

h2           { margin: 1.3em 0 0.0 0; padding: 9px;
               background: #bc2131; color: #000000; }
h2.traceback, h3.traceback {
    color: #ffffff;
    border-top-right-radius: 4px;
    border-top-left-radius: 4px;
}
h2 small, h3 small { font-style: normal; color: #ffffff; font-weight: normal; }

div.traceback {
    border-bottom-left-radius: 4px;
    border-bottom-right-radius: 1px;
}
div.traceback, div.plain { border: 1px solid #ddd; margin: 0 0 1em 0; padding: 10px; }
div.plain p      { margin: 0; }
div.plain textarea,
div.plain pre { margin: 10px 0 0 0; padding: 4px;
                background-color: #eeeeee; border: 1px solid #dddddd; }
div.plain textarea { width: 99%; height: 300px; }
div.traceback h3 { margin: 0; }
div.traceback ul { list-style: none; margin: 0; padding: 0; }
div.traceback h4 { font-size: 13px; font-weight: normal; margin: 5px 0; }
div.traceback pre { margin: 0; padding: 5px 0 3px 5px;
                    background-color: #f5f5f5;}
div.traceback pre,
div.box table.source { white-space: pre-wrap;       /* css-3 should we be so lucky... */
                       white-space: -moz-pre-wrap;  /* Mozilla, since 1999 */
                       white-space: -pre-wrap;      /* Opera 4-6 ?? */
                       white-space: -o-pre-wrap;    /* Opera 7 ?? */
                       word-wrap: break-word;       /* Internet Explorer 5.5+ */
                       _white-space: pre;           /* IE only hack to re-specify in
                                                    addition to word-wrap  */ }
div.box h2 { color: #ffffff; }
div.traceback pre:hover { background-color: #eeeeee; color: black; cursor: pointer; }
div.traceback blockquote { margin: 1em 0 0 0; padding: 0; }
div.traceback img { float: right; padding: 2px; margin: -3px 2px 0 0; cursor: pointer; }
div.traceback img:hover { background-color: #ddd; border-color: #eeeeee; }
div.traceback pre:hover img { display: block; }
div.traceback cite.filename { font-style: normal; color: #666666; }

pre.console { border: 1px solid #ccc; background: white!important;
              color: black; padding: 5px!important;
              margin: 3px 0 0 0!important; cursor: default!important;
              overflow: auto; }
pre.console form { color: #555; }
pre.console input { background-color: transparent; color: #555;
                    width: 90%; font-family: Consolas, "andale mono", "lucida console", monospace; font-size: 14px;
                     border: none!important; }

span.string { color: #30799B; }
span.number { color: #9C1A1C; }
span.help   { color: #3A7734; }
span.object { color: #485F6E; }

pre.console div.traceback,
pre.console div.box { margin: 5px; white-space: normal;
                      border: 1px solid #dddddd; padding: 5px;
                      font-family: sans-serif;  }
pre.console div.box h3,
pre.console div.traceback h3 { margin: -5px -5px 5px -5px; padding: 5px;
                               background: #bc2131; color: #ffffff; }

pre.console div.traceback pre:hover { cursor: default; background: #eeeeee; }
pre.console div.traceback pre.syntaxerror { background: #eeeeee; border: none;
                                            margin: 20px -10px -10px -10px;
                                            padding: 10px; border-top: 1px solid #dddddd; }
pre.console div.noframe-traceback pre.syntaxerror { margin-top: -10px; border: none; }

pre.console div.box pre.repr { padding: 0; margin: 0; background-color: white; border: none; }
pre.console div.box table { margin-top: 6px; }
pre.console div.box pre { border: none; }
pre.console div.box pre.help { background-color: white; }
pre.console div.box pre.help:hover { cursor: default; }
pre.console table tr { vertical-align: top; }
pre.console table th { white-space: nowrap; }
div.console { border: 1px solid #dddddd; padding: 4px; background-color: #f5f5f5; }

div.box table.source { border-collapse: collapse; width: 100%; background: #f5f5f5;
	font-size: 12px;
}
div.box table.source td { border-top: 1px solid #dddddd; padding: 4px 0 4px 10px; }
div.box table.source td.lineno { color: #999; padding-right: 10px; width: 1px; }
div.box table.source tr.in-frame { background-color: white; }
div.box table.source tr.current { background-color: #dddddd; color: #e5762b; }
div.sourceview { overflow: auto; border: 1px solid #ccc; }
